@@ -1,3 +1,7 @@
+# following upgrade request 070122
+
+   if(!exists("Sys.setenv", envir = baseenv()))
+     Sys.setenv <- Sys.putenv
 
 
 #.First.lib <- function(lib, pkg) {
@@ -5,9 +9,9 @@
   require(methods, quietly = TRUE, warn.conflicts = FALSE)
   require(sp)
   .rgdal_old.PROJ_LIB <- Sys.getenv("PROJ_LIB")
-  Sys.putenv("PROJ_LIB"=system.file("proj", package = "rgdal")[1])
+  Sys.setenv("PROJ_LIB"=system.file("proj", package = "rgdal")[1])
   .rgdal_old.GDAL_DATA <- Sys.getenv("GDAL_DATA")
-  Sys.putenv("GDAL_DATA"=system.file("gdal", package = "rgdal")[1])
+  Sys.setenv("GDAL_DATA"=system.file("gdal", package = "rgdal")[1])
 
   library.dynam('rgdal', pkg, lib)
 
@@ -20,7 +24,7 @@
 
 #.Last.lib <- function(lib, pkg) {
 .onUnload <- function(libpath) {
-    Sys.putenv("PROJ_LIB"=.rgdal_old.PROJ_LIB)
-    Sys.putenv("GDAL_DATA"=.rgdal_old.GDAL_DATA)
+    Sys.setenv("PROJ_LIB"=.rgdal_old.PROJ_LIB)
+    Sys.setenv("GDAL_DATA"=.rgdal_old.GDAL_DATA)
 }
 
